/*******************************************************************\

Module:

Author:

\*******************************************************************/


#ifndef CPROVER_CPP_CPP_UTIL_H
#define CPROVER_CPP_CPP_UTIL_H

#include <util/expr.h>
#include <util/symbol.h>

symbol_exprt cpp_symbol_expr(const symbolt &symbol);

#endif // CPROVER_CPP_CPP_UTIL_H
